@@ -90,12 +90,12 @@ class KdeFrontend(Frontend, QObject):
         #add any file sources passed
         if self.__img is not None:
             self.__backend.add_image(misc.text_type(self.__img))
-
-        downloadsDir = QDir(QStandardPaths.standardLocations(QStandardPaths.DownloadLocation)[0])
-        isoFilter = []
-        isoFilter.append("*.iso")
-        for iso in downloadsDir.entryList(isoFilter, QDir.Files):
-            self.__backend.add_image(misc.text_type(downloadsDir.absoluteFilePath(iso)))
+        else:
+            downloadsDir = QDir(QStandardPaths.standardLocations(QStandardPaths.DownloadLocation)[0])
+            isoFilter = []
+            isoFilter.append("*.iso")
+            for iso in downloadsDir.entryList(isoFilter, QDir.Files):
+                self.__backend.add_image(misc.text_type(downloadsDir.absoluteFilePath(iso)))
 
         def test_func(*a):
             if not queue.empty():
@@ -137,7 +137,7 @@ class KdeFrontend(Frontend, QObject):
         uic.loadUi(misc.text_type(appdir + "/" + self.__mainWindow_ui), self.__mainWindow)
 
         #hide sources if an argument was provided
-        if self.__img is not '':
+        if self.__img != '':
             self.__mainWindow.ui_source_list.hide()
             self.__mainWindow.ui_add_source.hide()
             self.__mainWindow.source_label.hide()
